/**********************************************************************
 * Copyright (c) 2004 IBM Corporation and others. All rights reserved.   This
 * program and the accompanying materials are made available under the terms of
 * the Common Public License v1.0 which accompanies this distribution, and is
 * available at http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.core.resources.refresh.linux;

/**
 * Method stubs for interacting with linux auto-refresh natives.
 */
public class LinuxNatives {
	static {
		System.loadLibrary("refresh"); //$NON-NLS-1$
	}
	/**
	 * Used for debugging from within the natives.
	 * 
	 * @param string A message.
	 */
	public static void PrintString (String string) {
		System.out.print (string);
	}
	
	/**
	 * Instructs the natives to add a new directory to the list to be monitored.
	 * 
	 * @param path Location of a directory to monitor
	 * @return a handle to the directory monitor to be used in RemoveMonitor(), or 0
	 * if adding the monitor failed
	 */
	public static native int AddDirectoryMonitor (String path);
	
	/**
	 * Inform the natives to stop monitoring the directory denoted by the monitor_handle.
	 * 
	 * @param monitor_handle the handle of the monitor created from AddDirectoryMonitor()
	 * @return boolean true if monitoring was stopped, else false
	 */
	public static native boolean RemoveMonitor (int monitor_handle);

	/**
	 * Blocks waiting for the next filesystem event to be generated by the native monitor.
	 * 
	 * @return MonitorEvent
	 */
	public static native MonitorEvent GetNextEvent ();
	
	/**
	 * Checks if there is a new event that was generated by the native monitor. 
	 * 
	 * @return true if there is a pending event, and false otherwise.
	 */
	public static native boolean PendingEvents();
	/**
	 * Closes the FAM connection and cleans up any allocated monitors
	 * 
	 * @return true if successful, and false otherwise
	 */
	public static native boolean FAMClose();
}
