/**********************************************************************
 * Copyright (c) 2004 IBM Corporation and others. All rights reserved.   This
 * program and the accompanying materials are made available under the terms of
 * the Common Public License v1.0 which accompanies this distribution, and is
 * available at http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.core.resources.refresh.linux;

/**
 * Object generated by the Linux Natives for returning information
 * about filesystem events to a  Monitor object
 */
public class MonitorEvent {
	public static final int EVENT_TYPE_CHANGED = 0;
	public static final int EVENT_TYPE_CREATED = 1;
	public static final int EVENT_TYPE_DELETED = 2;
	public static final int EVENT_START_EXEC = 3;
	public static final int EVENT_STOP_EXEC = 4;
	public static final int EVENT_ACK = 5;
	public static final int EVENT_EXISTS = 6;
	public static final int EVENT_END_EXIST = 7;
	public static final int EVENT_MOVED = 8;
	public static final int EVENT_OTHER = 9;
	
	private String filename;
	private int eventType;

	public MonitorEvent (String filename, int eventType) {
		setFilename(filename);
		setEventType(eventType);	
	}
	public void setFilename(String filename) {
		this.filename= filename;
	}
	public String getFilename() {
		return filename;
	}
	public void setEventType(int eventType) {
		this.eventType= eventType;
	}
	public int getEventType() {
		return eventType;
	}
	/**
	 * For debugging purposes only
	 */
	public String toString() {
		StringBuffer buf = new StringBuffer("MonitorEvent("); //$NON-NLS-1$
		switch (eventType) {
			case EVENT_TYPE_CHANGED:
				buf.append("EVENT_TYPE_CHANGED"); //$NON-NLS-1$
				break;
			case EVENT_TYPE_CREATED:
				buf.append("EVENT_TYPE_CREATED"); //$NON-NLS-1$
				break;
			case EVENT_TYPE_DELETED:
				buf.append("EVENT_TYPE_DELETED"); //$NON-NLS-1$
				break;
			case EVENT_START_EXEC:
				buf.append("EVENT_START_EXEC"); //$NON-NLS-1$
				break;
			case EVENT_STOP_EXEC:
				buf.append("EVENT_STOP_EXEC"); //$NON-NLS-1$
				break;
			case EVENT_ACK:
				buf.append("EVENT_ACK"); //$NON-NLS-1$
				break;
			case EVENT_EXISTS:
				buf.append("EVENT_EXISTS"); //$NON-NLS-1$
				break;
			case EVENT_END_EXIST:
				buf.append("EVENT_END_EXIST"); //$NON-NLS-1$
				break;
			case EVENT_MOVED:
				buf.append("EVENT_MOVED"); //$NON-NLS-1$
				break;
			case EVENT_OTHER:
				buf.append("EVENT_OTHER"); //$NON-NLS-1$
				break;
			default:
				buf.append(eventType);
				break;
		}
		buf.append(", "); //$NON-NLS-1$
		buf.append(filename);
		buf.append(')');
		return buf.toString();
	}
}