/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others. All rights reserved.
 * This program and the accompanying materials are made available under the
 * terms of the Common Public License v1.0 which accompanies this distribution,
 * and is available at http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: IBM Corporation - initial API and implementation
 ******************************************************************************/
package org.eclipse.search.ui;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
/**
 * Represents a particular search query (e.g. "find all occurrences of 'foo' in
 * workspace"). When executed, the query must update its ISearchResult
 * with the results of the query. This interface must be implemented by
 * clients.
 * 
 * This API is preliminary and subject to change at any time.
 * 
 * @since 3.0
 */
public interface ISearchQuery {
	/**
	 * Runs this query.
	 * 
	 * @param monitor The progress monitor to be used
	 * @return The status after completion of the search job.
	 */
	IStatus run(IProgressMonitor monitor);
	/**
	 * Returns the a user readeable label for this query. This will be used, for example to
	 * set the <code>Job</code> name if this query is executed in the
	 * background.
	 * 
	 * @return The user readeable label of this query.
	 */
	String getLabel();
	/**
	 * Returns whether the query can be run more than once. Some queries may depend on transient
	 * information. 
	 * @return Whether this query can be run more than once.
	 */
	boolean canRerun();
	/**
	 * Returns whether this query can be run in the background. Note that queries must do proper locking 
	 * when they are run in the background (e.g. get the appropriate workspace locks). 
	 * @return Whether this query can be run in the background.
	 */
	boolean canRunInBackground();
	/**
	 * Returns the search result associated with this query.
	 * @return This query's search result.
	 */
	ISearchResult getSearchResult();
}
