/*******************************************************************************
 * Copyright (c) 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.ui.internal;

import org.eclipse.swt.graphics.Point;
import org.eclipse.ui.presentations.IPresentablePart;
import org.eclipse.ui.presentations.IStackPresentationSite;
import org.eclipse.ui.presentations.StackPresentation;

/**
 * @since 3.0
 */
public class DefaultStackPresentationSite implements IStackPresentationSite {
	
	private StackPresentation presentation;
	private int state = IStackPresentationSite.STATE_RESTORED;
	
	public DefaultStackPresentationSite() {
		
	}
	
	public void setPresentation(StackPresentation newPresentation) {
		presentation = newPresentation;
		if (presentation != null) {
			presentation.setState(state);
		}
	}
	
	public StackPresentation getPresentation() {
		return presentation;
	}
	
	public int getState() {
		return state;
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.ui.internal.skins.IStackPresentationSite#selectPart(org.eclipse.ui.internal.skins.IPresentablePart)
	 */
	public void selectPart(IPresentablePart toSelect) {
		
		if (presentation != null) {
			presentation.selectPart(toSelect);
		}
	}
	
	public void dispose() {
		if (presentation != null) {
			presentation.dispose();	
		}
		setPresentation(null);
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.ui.internal.skins.IPresentationSite#setState(int)
	 */
	public void setState(int newState) {
		setPresentationState(newState);
	}
	
	public void setPresentationState(int newState) {
		state = newState;
		if (presentation != null) {
			presentation.setState(newState);
		}		
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.ui.internal.skins.IPresentablePart#isClosable()
	 */
	public boolean isCloseable(IPresentablePart part) {
		return true;
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.ui.internal.skins.IPresentablePart#isMovable()
	 */
	public boolean isMoveable(IPresentablePart part) {
		return true;
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.ui.internal.skins.IPresentationSite#dragStart(org.eclipse.ui.internal.skins.IPresentablePart, boolean)
	 */
	public void dragStart(IPresentablePart beingDragged, Point initialPosition, boolean keyboard) {

	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.ui.internal.skins.IPresentationSite#close(org.eclipse.ui.internal.skins.IPresentablePart)
	 */
	public void close(IPresentablePart toClose) {
		// TODO Auto-generated method stub
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.ui.internal.skins.IPresentationSite#dragStart(boolean)
	 */
	public void dragStart(Point initialPosition, boolean keyboard) {
		// TODO Auto-generated method stub
	}

}
